==> jc-1.4.5.tar.gz: javax/swing/plaf/metal/MetalSplitPaneUI.h <==
// public class javax.swing.plaf.metal.MetalSplitPaneUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 1ff15ea0dff4e669 javax_swing_plaf_SplitPaneUI
// @dep_class 479ee75f33e1b1ea javax_swing_plaf_basic_BasicSplitPaneUI
// @dep_class 185743e905769ac5 javax_swing_plaf_metal_MetalSplitPaneUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicSplitPaneUI

#include "javax/swing/plaf/basic/BasicSplitPaneUI.h"

#ifndef _JC_javax_swing_plaf_metal_MetalSplitPaneUI_H_
#define _JC_javax_swing_plaf_metal_MetalSplitPaneUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_refs	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_nonrefs	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$refs	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$refs;
typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$nonrefs	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$object	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$object;

typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$fields_struct	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$fields_struct;
typedef const struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vmethods	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtable	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtype	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$fields_struct {
	struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$object	*instance;
};
extern _jc_javax_swing_plaf_metal_MetalSplitPaneUI$fields_struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_metal_MetalSplitPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_javax_swing_plaf_metal_MetalSplitPaneUI$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_metal_MetalSplitPaneUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vmethods {
};

// Vtable
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_SplitPaneUI$vmethods	javax_swing_plaf_SplitPaneUI;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI$vmethods	javax_swing_plaf_basic_BasicSplitPaneUI;
	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vmethods	javax_swing_plaf_metal_MetalSplitPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$refs {
    _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_refs	javax_swing_plaf_metal_MetalSplitPaneUI;
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI$sub_refs	javax_swing_plaf_basic_BasicSplitPaneUI;
    _jc_javax_swing_plaf_SplitPaneUI$sub_refs	javax_swing_plaf_SplitPaneUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_SplitPaneUI$sub_nonrefs	javax_swing_plaf_SplitPaneUI;
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI$sub_nonrefs	javax_swing_plaf_basic_BasicSplitPaneUI;
    _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_nonrefs	javax_swing_plaf_metal_MetalSplitPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$object {
	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtype _jc_javax_swing_plaf_metal_MetalSplitPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_metal_MetalSplitPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_metal_MetalSplitPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_metal_MetalSplitPaneUI_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/metal/MetalSplitPaneUI.h <==
// public class javax.swing.plaf.metal.MetalSplitPaneUI

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9f393451fe8ae81c javax_swing_plaf_ComponentUI
// @dep_class 1ff15ea0dff4e669 javax_swing_plaf_SplitPaneUI
// @dep_class 880ff797bc495b02 javax_swing_plaf_basic_BasicSplitPaneUI
// @dep_class 8b62715324be21bf javax_swing_plaf_metal_MetalSplitPaneUI

// header file dependencies
// @dep_header javax_swing_plaf_basic_BasicSplitPaneUI

#include "javax/swing/plaf/basic/BasicSplitPaneUI.h"

#ifndef _JC_javax_swing_plaf_metal_MetalSplitPaneUI_H_
#define _JC_javax_swing_plaf_metal_MetalSplitPaneUI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_javax_swing_JComponent$object;
struct _jc_javax_swing_plaf_ComponentUI$object;
struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_refs	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_refs;
typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_nonrefs	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$refs	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$refs;
typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$nonrefs	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$nonrefs;
typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$object	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$object;

typedef struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$fields_struct	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$fields_struct;
typedef const struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vmethods	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vmethods;
typedef const struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtable	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtable;
typedef const struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtype	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$fields_struct {
	struct _jc_java_util_HashMap$object	*instances;
};
extern _jc_javax_swing_plaf_metal_MetalSplitPaneUI$fields_struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_metal_MetalSplitPaneUI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider$object *_jc_javax_swing_plaf_metal_MetalSplitPaneUI$method$createDefaultDivider$81b26fe252871459(_jc_env *, struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_metal_MetalSplitPaneUI$method_info$createDefaultDivider$81b26fe252871459;

// Static methods
extern struct _jc_javax_swing_plaf_ComponentUI$object *_jc_javax_swing_plaf_metal_MetalSplitPaneUI$method$createUI$32e25151aaddad9d(_jc_env *, struct _jc_javax_swing_JComponent$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vmethods {
	struct _jc_javax_swing_plaf_basic_BasicSplitPaneDivider$object	*(*createDefaultDivider$81b26fe252871459)(_jc_env *, struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_ComponentUI$vmethods	javax_swing_plaf_ComponentUI;
	_jc_javax_swing_plaf_SplitPaneUI$vmethods	javax_swing_plaf_SplitPaneUI;
	_jc_javax_swing_plaf_basic_BasicSplitPaneUI$vmethods	javax_swing_plaf_basic_BasicSplitPaneUI;
	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vmethods	javax_swing_plaf_metal_MetalSplitPaneUI;
};

// Vtype
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$refs {
    _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_refs	javax_swing_plaf_metal_MetalSplitPaneUI;
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI$sub_refs	javax_swing_plaf_basic_BasicSplitPaneUI;
    _jc_javax_swing_plaf_SplitPaneUI$sub_refs	javax_swing_plaf_SplitPaneUI;
    _jc_javax_swing_plaf_ComponentUI$sub_refs	javax_swing_plaf_ComponentUI;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_ComponentUI$sub_nonrefs	javax_swing_plaf_ComponentUI;
    _jc_javax_swing_plaf_SplitPaneUI$sub_nonrefs	javax_swing_plaf_SplitPaneUI;
    _jc_javax_swing_plaf_basic_BasicSplitPaneUI$sub_nonrefs	javax_swing_plaf_basic_BasicSplitPaneUI;
    _jc_javax_swing_plaf_metal_MetalSplitPaneUI$sub_nonrefs	javax_swing_plaf_metal_MetalSplitPaneUI;
};

// Object instance structure
struct _jc_javax_swing_plaf_metal_MetalSplitPaneUI$object {
	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtype	*vtype;
	_jc_javax_swing_plaf_metal_MetalSplitPaneUI$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_metal_MetalSplitPaneUI$vtype _jc_javax_swing_plaf_metal_MetalSplitPaneUI$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_metal_MetalSplitPaneUI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_metal_MetalSplitPaneUI$class_object;

#endif	/* _JC_javax_swing_plaf_metal_MetalSplitPaneUI_H_ */
